import uvicorn
from fastapi import FastAPI
from fastapi_health import health

from dashboard.models import Settings
from dashboard.api import temp
from dashboard.views import form, homepage


def is_storage_writable():
    return settings.data.exists()


def healthy_status():
    return {"storage": "ok" if is_storage_writable() else "not writable"}


def main():
    uvicorn.run(
        "dashboard.main:app",
        host="0.0.0.0",
        port=5000,  # default port is 8000
        reload=True,
    )


settings = Settings()

app = FastAPI()
app.include_router(temp.router)
app.include_router(form.router)
app.include_router(homepage.router)

app.add_api_route("/healthz", health(conditions=[is_storage_writable, healthy_status]))

if __name__ == "__main__":
    main()
